==> scorched3d_38.1.orig.tar.gz: scorched3d-38.1/src/server/ServerAddPlayerHandler.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#if !defined(__INCLUDE_ServerAddPlayerHandlerh_INCLUDE__)
#define __INCLUDE_ServerAddPlayerHandlerh_INCLUDE__

#include <coms/ComsMessageHandler.h>

class ServerAddPlayerHandler : 
	public ComsMessageHandlerI
{
public:
	static ServerAddPlayerHandler *instance();

	virtual bool processMessage(unsigned int id,
		const char *messageType,
		NetBufferReader &reader);

protected:
	static ServerAddPlayerHandler *instance_;

	void getUniqueName(std::string &sentname);

private:
	ServerAddPlayerHandler();
	virtual ~ServerAddPlayerHandler();
};

#endif

==> scorched3d_41.2dfsg.orig.tar.gz: scorched3d-41.2dfsg/src/server/ServerAddPlayerHandler.h <==
////////////////////////////////////////////////////////////////////////////////
//    Scorched3D (c) 2000-2003
//
//    This file is part of Scorched3D.
//
//    Scorched3D is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//    Scorched3D is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Scorched3D; if not, write to the Free Software
//    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
////////////////////////////////////////////////////////////////////////////////

#if !defined(__INCLUDE_ServerAddPlayerHandlerh_INCLUDE__)
#define __INCLUDE_ServerAddPlayerHandlerh_INCLUDE__

#include <coms/ComsMessageHandler.h>

class Tank;
class ServerAddPlayerHandler : 
	public ComsMessageHandlerI
{
public:
	static ServerAddPlayerHandler *instance();

	virtual bool processMessage(
		NetMessage &message,
		const char *messageType,
		NetBufferReader &reader);

protected:
	static ServerAddPlayerHandler *instance_;

	void getUniqueName(Tank *tank, std::string &sentname);
	void filterName(Tank *tank, std::string &sentname);

private:
	ServerAddPlayerHandler();
	virtual ~ServerAddPlayerHandler();
};

#endif
